SpeedDialFabWidget class

Inheritance

Constructors

SpeedDialFabWidget({Key? key, Color secondaryBackgroundColor = Colors.white, Color secondaryForegroundColor = Colors.black, Color primaryBackgroundColor = Colors.white, Color primaryForegroundColor = Colors.black, IconData primaryIconCollapse = Icons.expand_less, IconData primaryIconExpand = Icons.expand_less, double rotateAngle = math.pi, required List<IconData> secondaryIconsList, required List<Function> secondaryIconsOnPress, List<String>? secondaryIconsText, double primaryElevation = 5.0, double secondaryElevation = 10.0, Duration animationDuration = const Duration(milliseconds: 500), SpeedDialLayout layout = SpeedDialLayout.vertical, SpeedDialDirection direction = SpeedDialDirection.up, double radialRadius = 112.0, double radialStartAngle = math.pi, double radialSweepAngle = -math.pi / 2, bool glassEffect = false, Color glassColor = Colors.white, double glassOpacity = 0.22, double glassBlurSigma = 14.0, bool blurBackground = false, double blurBackgroundSigma = 5.0})
const

Properties

animationDuration → Duration
Length of the expand and collapse animation.
final
blurBackground → bool
Preserves the original API for blurring the screen behind the dial.
final
blurBackgroundSigma → double
Blur strength used by blurBackground.
final
direction → SpeedDialDirection
Direction for SpeedDialLayout.vertical and SpeedDialLayout.horizontal.
final
glassBlurSigma → double
Blur strength of a glass action surface.
final
glassColor → Color
Color mixed into a glass action surface.
final
glassEffect → bool
Applies a translucent, blurred glass surface to the action buttons. This uses Flutter's BackdropFilter, including on iOS.
final
glassOpacity → double
Opacity of glassColor when glassEffect is enabled.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
layout → SpeedDialLayout
Arrangement of the secondary actions.
final
primaryBackgroundColor → Color
final
primaryElevation → double
final
primaryForegroundColor → Color
final
primaryIconCollapse → IconData
final
primaryIconExpand → IconData
final
radialRadius → double
Distance from the primary action's center in radial mode.
final
radialStartAngle → double
First angle in radians for radial mode. The default fans up and left, which keeps actions visible when the FAB is in the bottom-right corner.
final
radialSweepAngle → double
Sweep in radians for radial mode. Negative values travel counter-clockwise.
final
rotateAngle → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryBackgroundColor → Color
final
secondaryElevation → double
final
secondaryForegroundColor → Color
final
secondaryIconsList → List<IconData>
final
secondaryIconsOnPress → List<Function>
final
secondaryIconsText → List<String>?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<SpeedDialFabWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited